pub struct CreateNestOptions {
pub author: CompactString,
pub name: CompactString,
pub description: Option<CompactString>,
}Fields
name: CompactStringdescription: Option<CompactString>Trait Implementations
Sourceimpl ComposeSchema for CreateNestOptions
impl ComposeSchema for CreateNestOptions
Sourceimpl<'de> Deserialize<'de> for CreateNestOptions
impl<'de> Deserialize<'de> for CreateNestOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl ToSchema for CreateNestOptions
impl ToSchema for CreateNestOptions
Sourceimpl Validate for CreateNestOptions
impl Validate for CreateNestOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for CreateNestOptions
impl RefUnwindSafe for CreateNestOptions
impl Send for CreateNestOptions
impl Sync for CreateNestOptions
impl Unpin for CreateNestOptions
impl UnwindSafe for CreateNestOptions