pub struct UpdateNestOptions {
pub author: Option<CompactString>,
pub name: Option<CompactString>,
pub description: Option<Option<CompactString>>,
}Fields
name: Option<CompactString>description: Option<Option<CompactString>>Trait Implementations
Sourceimpl Clone for UpdateNestOptions
impl Clone for UpdateNestOptions
Sourcefn clone(&self) -> UpdateNestOptions
fn clone(&self) -> UpdateNestOptions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for UpdateNestOptions
impl ComposeSchema for UpdateNestOptions
Sourceimpl Default for UpdateNestOptions
impl Default for UpdateNestOptions
Sourcefn default() -> UpdateNestOptions
fn default() -> UpdateNestOptions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for UpdateNestOptions
impl<'de> Deserialize<'de> for UpdateNestOptions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for UpdateNestOptions
impl Serialize for UpdateNestOptions
Sourceimpl ToSchema for UpdateNestOptions
impl ToSchema for UpdateNestOptions
Sourceimpl Validate for UpdateNestOptions
impl Validate for UpdateNestOptions
Sourcefn validate_into(
&self,
__garde_user_ctx: &Self::Context,
__garde_path: &mut dyn FnMut() -> Path,
__garde_report: &mut Report,
)
fn validate_into( &self, __garde_user_ctx: &Self::Context, __garde_path: &mut dyn FnMut() -> Path, __garde_report: &mut Report, )
Validates
Self, aggregating all validation errors into Report.fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
fn validate(&self) -> Result<(), Report>where
Self::Context: Default,
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read morefn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
fn validate_with(&self, ctx: &Self::Context) -> Result<(), Report>
Validates
Self, returning an Err with an aggregate of all errors if
the validation failed. Read moreAuto Trait Implementations
impl Freeze for UpdateNestOptions
impl RefUnwindSafe for UpdateNestOptions
impl Send for UpdateNestOptions
impl Sync for UpdateNestOptions
impl Unpin for UpdateNestOptions
impl UnwindSafe for UpdateNestOptions